widgetsnbextension: Jupyter interactive widgets for Jupyter Notebook
====================================================================

Description
-----------

Jupyter interactive widgets for Jupyter Notebook

License
-------

BSD 3-Clause License

Upstream Contact
----------------

https://pypi.org/project/widgetsnbextension/

